Package: flowUtils
Type: Package
Title: Utilities for flow cytometry
Version: 1.59.0
Author: J. Spidlen., N. Gopalakrishnan, F. Hahne, B. Ellis, R. Gentleman, M. Dalphin, N. Le Meur, B. Purcell, W. Jiang
Maintainer: Josef Spidlen <jspidlen@gmail.com>
Description: Provides utilities for flow cytometry data. 
Depends: R (>= 2.2.0)
Imports: Biobase, graph, methods, stats, utils, corpcor, RUnit, XML,
        flowCore (>= 1.32.0)
Suggests: gatingMLData
Collate: AllClasses.R gatingML.R helperFunctions.R gate-methods.R
        transforms.R parameter-methods.R compensation.R
        workflow2FlowJo.R writeGatingML.R zzz.R
License: Artistic-2.0
biocViews: ImmunoOncology, Infrastructure, FlowCytometry,
        CellBasedAssays, DecisionTree
URL: https://github.com/jspidlen/flowUtils
BugReports: https://github.com/jspidlen/flowUtils/issues
git_url: https://git.bioconductor.org/packages/flowUtils
git_branch: master
git_last_commit: 94ef3ef
git_last_commit_date: 2021-10-26
Date/Publication: 2021-10-26
NeedsCompilation: no
Packaged: 2021-10-26 21:16:25 UTC; biocbuild
Built: R 4.6.1; ; 2026-07-16 14:33:21 UTC; unix
