  fcsFile<-system.file("extdata/List-modeDataFiles","int-gating_test_file_4D.fcs",package="gatingMLData")
  gateFile <- system.file("extdata/Gating-MLFiles","10PolytopeGates.xml",package="gatingMLData")
  csvFile<-paste(system.file("extdata/ExpectedResults/10PolytopeGates",package="gatingMLData"))
  flowEnv=new.env()
  read.gatingML(gateFile,flowEnv)
  fcs <- read.FCS(fcsFile,transformation=FALSE)
 
test.polytope_01i<- function() {
  gateId<-"polytope_01i"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_02i<- function() {
  gateId<-"polytope_02i"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_03o<- function() {
  gateId<-"polytope_03o"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_04i<- function() {
  gateId<-"polytope_04i"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_05i<- function() {
  gateId<-"polytope_05i"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_06o<- function() {
  gateId<-"polytope_06o"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_07o<- function() {
  gateId<-"polytope_07o"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_08i<- function() {
  gateId<-"polytope_08i"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_09o<- function() {
  gateId<-"polytope_09o"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_10i<- function() {
  gateId<-"polytope_10i"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_11i<- function() {
  gateId<-"polytope_11i"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_12o<- function() {
  gateId<-"polytope_12o"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_13i<- function() {
  gateId<-"polytope_13i"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_14o<- function() {
  gateId<-"polytope_14o"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_15i<- function() {
  gateId<-"polytope_15i"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_16o<- function() {
  gateId<-"polytope_16o"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_17o<- function() {
  gateId<-"polytope_17o"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_18i<- function() {
  gateId<-"polytope_18i"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_19i<- function() {
  gateId<-"polytope_19i"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_20o<- function() {
  gateId<-"polytope_20o"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

test.polytope_21o<- function() {
  gateId<-"polytope_21o"
      csvFile<-paste(csvFile,"/",gateId,".txt",sep="")
      expectedResult<-read.csv(csvFile,header=TRUE)
      flowUtils:::performGateTest(gateId,fcs,expectedResult,flowEnv)
}

